==> ejc-front-impl-3.0.1-20211203.013507-94-sources.jar: com/ejianc/foundation/front/business/ide/entity/IdeRelease.java <==
package com.ejianc.foundation.front.business.ide.entity;

import java.io.Serializable;
import java.util.Date;

public class IdeRelease implements Serializable {

	private static final long serialVersionUID = 1L;

	private Long id;
	private Long appId; // 应用id
	private Long releaseGroupId; // 发版分组id
	private Date releaseTime; // 发版时间

	private Date createDate;
	private Long createId;
	private Integer isDelete;
	private Date modifyDate;
	private Long modifyId;
	private String version; // 版本号

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public Long getReleaseGroupId() {
		return releaseGroupId;
	}

	public void setReleaseGroupId(Long releaseGroupId) {
		this.releaseGroupId = releaseGroupId;
	}

	public Date getReleaseTime() {
		return releaseTime;
	}

	public void setReleaseTime(Date releaseTime) {
		this.releaseTime = releaseTime;
	}

	public Date getCreateDate() {
		return createDate;
	}

	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	public Long getCreateId() {
		return createId;
	}

	public void setCreateId(Long createId) {
		this.createId = createId;
	}

	public Integer getIsDelete() {
		return isDelete;
	}

	public void setIsDelete(Integer isDelete) {
		this.isDelete = isDelete;
	}

	public Date getModifyDate() {
		return modifyDate;
	}

	public void setModifyDate(Date modifyDate) {
		this.modifyDate = modifyDate;
	}

	public Long getModifyId() {
		return modifyId;
	}

	public void setModifyId(Long modifyId) {
		this.modifyId = modifyId;
	}

	public String getVersion() {
		return version;
	}

	public void setVersion(String version) {
		this.version = version;
	}

}

==> ejc-front-impl-3.0.1-20251107.081732-193-sources.jar: com/ejianc/foundation/front/business/ide/entity/IdeRelease.java <==
package com.ejianc.foundation.front.business.ide.entity;

import java.io.Serializable;
import java.util.Date;

public class IdeRelease implements Serializable {

	private static final long serialVersionUID = 1L;

	private Long id;
	private Long appId; // 应用id
	private Long releaseGroupId; // 发版分组id
	private Date releaseTime; // 发版时间

	private Date createDate;
	private Long createId;
	private String createName;
	private Integer isDelete;
	private Date modifyDate;
	private Long modifyId;
	private String version; // 版本号

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public Long getReleaseGroupId() {
		return releaseGroupId;
	}

	public void setReleaseGroupId(Long releaseGroupId) {
		this.releaseGroupId = releaseGroupId;
	}

	public Date getReleaseTime() {
		return releaseTime;
	}

	public void setReleaseTime(Date releaseTime) {
		this.releaseTime = releaseTime;
	}

	public Date getCreateDate() {
		return createDate;
	}

	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	public Long getCreateId() {
		return createId;
	}

	public void setCreateId(Long createId) {
		this.createId = createId;
	}

	public Integer getIsDelete() {
		return isDelete;
	}

	public void setIsDelete(Integer isDelete) {
		this.isDelete = isDelete;
	}

	public Date getModifyDate() {
		return modifyDate;
	}

	public void setModifyDate(Date modifyDate) {
		this.modifyDate = modifyDate;
	}

	public Long getModifyId() {
		return modifyId;
	}

	public void setModifyId(Long modifyId) {
		this.modifyId = modifyId;
	}

	public String getVersion() {
		return version;
	}

	public void setVersion(String version) {
		this.version = version;
	}

	public String getCreateName() {
		return createName;
	}

	public void setCreateName(String createName) {
		this.createName = createName;
	}
}
